
SortFaces::usage = "SortFaces[faces, vertex], where faces are the faces of a polyhedron (lists of indices of vertices) and vertex is an an index, gives the faces surrounding the vertex in geometric order."

SortFaces[faces_, vertex_] := Module[
	{unsorted, face, sorted, n, circlingvertex, i},
	unsorted = Select[faces, MemberQ[#, vertex]&];
	face = First @ unsorted;
	sorted = {face};
	unsorted = Rest @ unsorted;
	n = Length @ unsorted;
	circlingvertex = Last @ Neighbours[face, vertex];
	Do[
		face = First @ Select[unsorted, MemberQ[#, circlingvertex]&];
		AppendTo[sorted, face];
		unsorted = Complement[unsorted, {face}];
		circlingvertex = First @ Complement[Neighbours[face, vertex], 
			{circlingvertex}],
		{i, n}
	];
	sorted
]

SortEdges::usage = "SortEdges[faces, vertex], where faces are the faces of a 
polyhedron (lists of indices of vertices) and vertex is an an index, gives the 
indices of the vertices for the edges emanating from vertex in geometric 
order."

SortEdges[faces_, vertex_] := Module[
	{pairs, ends, i},
	pairs = Neighbours[#, vertex]& /@ SortFaces[faces, vertex];
	ends = Intersection[ pairs[[1]], pairs[[2]] ];
	Do[
		AppendTo[ends, First @ Complement[pairs[[i + 1]], ends]], 
		{i, Length @ pairs - 1}
	];
	{vertex, #}& /@ ends
]

