
Involute::usage = "Involute[f, s, n, du] gives graphics for the curve given 
by the function f: R -> R ^ 2 at n equally spaced points from -1 to 1 together
with the involute of the curve starting at s."

InvoluteAux1[f_, u_?NumberQ, n_:120, du_:.01] := Module[
	{r, s, p, f1, f2, k1, k2, a, k},
	r = Range[-1, 1, 2 / (n - 1)];
	s = Last @ ArcLengths @ Line[ f /@ Select[r, # <= u &]];
	p = Thread @ {r, # - s & /@ ArcLengths @ Line[f /@ r]};
	f1 = Tangent[f, #1, -#2, du] &;
	f2 = Tangent[f, #1,  #2, du] &;
	k1 = Apply[f1, #] & /@ p;
	k2 = Apply[f2, #] & /@ p;
	a = 2;
	k = k1;
	While[	a <= Length[k1], 
		k[[a]] = If[	Distance[k1[[a, 1, 2]], k[[a - 1, 1, 2]]] <= 
				Distance[k2[[a, 1, 2]], k[[a - 1, 1, 2]]], 
				k1[[a]], k2[[a]]]; 
		a++];
	k ] 

InvoluteAux2[f_, s_, n_:120, du_:.01] := Module[
	{aux, tangents, involute},
	aux = InvoluteAux1[f, s, n, du];
	tangents = {Cyan, Thickness[.0035], aux};
	involute = {Magenta, Thickness[.0035], Line[Last[Last[#]] & /@ aux]};
	{tangents, involute} ] 

Involute[f_, s_, n_:120, du_:.01] := Module[
	{curve, tangentsinvolute},
	curve = {Blue, Thickness[.0035], Line[f /@ Range[-1, 1, 2 / (n - 1)]]};
	tangentsinvolute = InvoluteAux2[f, s, n, du];
	{curve, tangentsinvolute, curve} ] 

