
Torsion::usage = "Torsion[f, u, du] is a measure of the rate of change of the 
osculating plane to the curve f: R -> R ^ 3 at f[u]."

ColouredTorsions::usage = "ColouredTorsions[f, du] gives the graph of the 
function f from -1 to 1 coloured according to the torsion."

( Torsion[f_, u_?NumberQ] := Block[
	{v, f1, f2, f3, g},
	f1 = D[f[v], v];
	f2 = D[  f1, v];
	f3 = D[  f2, v];
	g = Cross[f1, f2];
	N[f1 . Cross[f2, f3] / (g . g) /. v -> u] ] )

Torsion[f_, l_List] := Torsion[f, #] & /@ l

( ColouredTorsions[f_, l_List] := Block[
	{m, rgb1, max, min, t, rgb2, colours, lines},
	m = (Drop[l, 1] + Drop[l, -1]) / 2;
	rgb1 = 2 / N[Pi] Re @ ArcTan[Torsion[f, m]];
	max = Chop @ Max[rgb1];
	min = Chop @ Min[rgb1];
	If[min == max, rgb2 = Table[.5, {t, Length[l] - 1}], 
		rgb2 = (rgb1 - min) / (max - min)];
	colours =  RGBColor[#, 0, 1 - #] & /@ rgb2;
	lines = Line /@ Partition[f /@ l, 2, 1];
	Transpose[{colours, lines}] ] )


