
PreDraw3D::usage = "PreDraw3D[f] prepares the figure f for drawing in three 
dimensions."

( PreDraw3D[m_] := m 
	/; MemberQ[{Point, Polygon, GrayLevel, RGBColor, PointSize, 
	AbsolutePointSize, Thickness, AbsoluteThickness, FaceForm, EdgeForm}, 
	Head @ m] )

PreDraw3D @ Text[___] := {}

PreDraw3D @ Point @ x_ := Point @ ToTriple @ x 

PreDraw3D @ Line @ l_ := Line[ToTriple /@ l]

PreDraw3D @ Circle[c:{_, _, _}, r_] := 
	PreDraw3D @ Circle3D[c, c + r $i, c + r $j] 

PreDraw3D @ Circle[c:{_, _, _}, r_, n_] := 
	PreDraw3D @ Circle3D[c, c + r $i, c + r $j, n] 

PreDraw3D @ Circle3D[c_, d_, e_] := Module[{x, y}, 
	x = d - c; 
	y = Rotate[N[Pi/2], Line[{c, c + PlaneNormal[{c, d, e}]}]][d] - c; 
	Line @ Map[
		c + Cos[#] x + Sin[#] y &, 
		2 N[Pi] Range[0, 1, 1/$PointsOnCircle]
	]
]

PreDraw3D @ Circle3D[c_, d_, e_, n_] := Module[{x, y}, 
	x = d - c; 
	y = Rotate[N[Pi/2], Line[{c, c + PlaneNormal[{c, d, e}]}]][d] - c; 
	Line @ Map[
		c + Cos[#] x + Sin[#] y &, 
		2 N[Pi] Range[0, 1, 1 / n]
	]
]

PreDraw3D @ Cuboid @ x_ := Cuboid[ToTriple @ x]

PreDraw3D @ Cuboid[x1_, x2_] := Cuboid[ToTriple @ x1, ToTriple @ x2]

PreDraw3D @ Plane @ {p_, q_, r_} := PreDraw3D @ 
	OutlinePolygon[Polygon @ { q, r, 2 p - q, 2 p - r}, $PlaneOpening]

PreDraw3D @ Sphere[c_?PointQ, r_] := {EdgeForm[], Polygon /@ Flatten[
	Translate[c] 
		[r Map[
			Unit, 
			TriangulateTwice @ Vertices[Icosahedron] [[#]]& /@
				Faces[Icosahedron],
			{3}
		]], 
	1
]}

PreDraw3D @ OpenSphere[c_?PointQ, r_, s_] := 
{
	OutlinePolygon[Polygon @ #, s]& /@ Flatten[
			Translate[c] [r Map[
				Unit, 
				TriangulateTwice @ 
					Vertices[Icosahedron] [[#]]& /@
						Faces[Icosahedron],
				{3}
			]], 
			1
		]
}

PreDraw3D @ EdgelessOpenSphere[c_?PointQ, r_, s_] := 
{
	EdgelessOutlinePolygon[Polygon @ #, s]& /@ Flatten[
			Translate[c] [r Map[
				Unit, 
				TriangulateTwice @ 
					Vertices[Icosahedron] [[#]]& /@
						Faces[Icosahedron],
				{3}
			]], 
			1
		]
}

PreDraw3D @ h_List := PreDraw3D /@ h

