
TrihedronPlanes::usage = "TrihedronPlanes[f, l, x, n, du] gives graphics for 
the curve f: R -> R ^ 3 at n equally spaced points from -1 to 1 together with 
the osculating, normal and rectifying planes at f[l], where l is a list or a 
number."

TrihedronPlanes3D::usage = "TrihedronPlanes3D[f, l, x, n, du] gives graphics 
for the curve f: R -> R ^ 3 at n equally spaced points from -1 to 1 together 
with the osculating, normal and rectifying planes at f[l], where l is a list 
or a number. The curve is doubled."

AnimateTrihedronPlanes::usage = "AnimateTrihedronPlanes[f, T, l, x, du] gives 
T frames of an animation, showing the curve f: R -> R ^ 3 from -1 to 1 
together with its moving osculating, normal and rectifying planes."

TrihedronPlanes[f_, l_List, x_?NumberQ, n_:120, du_:.01] := 
	{
		{
		Thickness[.008], Blue, Line[f /@ Range[-1, 1, 2 / (n - 1)]]},
		{FaceForm[Blue, Blue], OsculatingPlane[f, l, x, du]},
		{FaceForm[Red, Red], NormalPlane[f, l, x, du]},
		{FaceForm[Green, Green], RectifyingPlane[f, l, x, du]}
	} 

TrihedronPlanes[f_, u_?NumberQ, x_?NumberQ, n_:120, du_:.01] := 
	TrihedronPlanes[f, {u}, x, n, du] 

TrihedronPlanes3D[f_, l_List, x_?NumberQ, n_:120, du_:.01] := 
	{
		{
			Thickness[.02], Blue, #, 
			Thickness[.008], Cyan, Translate[
				.01 ViewPoint /. Options[Graphics3D]] @ #
		} & @ Line[f /@ Range[-1, 1, 2 / (n - 1)]],
		{FaceForm[Blue, Blue], OsculatingPlane[f, l, x, du]},
		{FaceForm[Red, Red], NormalPlane[f, l, x, du]},
		{FaceForm[Green, Green], RectifyingPlane[f, l, x, du]}
	} 

TrihedronPlanes3D[f_, u_?NumberQ, x_?NumberQ, n_:120, du_:.01] := 
	TrihedronPlanes3D[f, {u}, x, n, du] 

AnimateTrihedronPlanes[f_, T_?NumberQ, x_?NumberQ, n_:120, du_:.01] := Module[
	{t},
	Table[
		Graphics3D[
			PreDraw3D @ TrihedronPlanes[f, t, x, n, du], 
			PlotRange -> PlotRangeGraphics3D[f]
		], 
		{t, -1, 1 - 2 / (T - 1), 2 / (T - 1)}
	] 
] 

AnimateTrihedronPlanes3D[f_, T_?NumberQ, x_?NumberQ, n_:120, du_:.01] := 
Module[
	{t},
	Table[
		Graphics3D[
			PreDraw3D @ TrihedronPlanes3D[f, t, x, n, du], 
			PlotRange -> PlotRangeGraphics3D[f]
		], 
		{t, -1, 1 - 2 / (T - 1), 2 / (T - 1)}
	] 
] 

